# mypy-boto3-medialive

[![PyPI - mypy-boto3-medialive](https://img.shields.io/pypi/v/mypy-boto3-medialive.svg?color=blue)](https://pypi.org/project/mypy-boto3-medialive)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-medialive.svg?color=blue)](https://pypi.org/project/mypy-boto3-medialive)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)

Type annotations for
[boto3.MediaLive 1.16.7](https://boto3.amazonaws.com/v1/documentation/api/1.16.7/reference/services/medialive.html#MediaLive) service
compatible with
[VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright)
and other tools.

Generated by [mypy-boto3-buider 3.2.2](https://github.com/vemel/mypy_boto3_builder).

More information can be found on [boto3-stubs](https://pypi.org/project/boto3-stubs/) page.

- [mypy-boto3-medialive](#mypy-boto3-medialive)
  - [How to install](#how-to-install)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)
    - [Waiters annotations](#waiters-annotations)
    - [Service Resource annotations](#service-resource-annotations)
    - [Other resources annotations](#other-resources-annotations)
    - [Collections annotations](#collections-annotations)
    - [Typed dictionations](#typed-dictionations)

## How to install

Install `boto3-stubs` for `MediaLive` service.

```bash
python -m pip install boto3-stubs[medialive]
```

## Usage

### VSCode

- Install [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `boto-stubs[medialive]` in your environment: `python -m pip install 'boto3-stubs[medialive]'`

Both type checking and auto-complete should work for `MediaLive` service.
No explicit type annotations required, write your `boto3` code as usual.

### PyCharm

- Install `boto-stubs[medialive]` in your environment: `python -m pip install 'boto3-stubs[medialive]'`

Both type checking and auto-complete should work for `MediaLive` service.
No explicit type annotations required, write your `boto3` code as usual.
Auto-complete can be slow on big projects or if you have a lot of installed `boto3-stubs` submodules.

### Other IDEs

Not tested, but as long as your IDE support `mypy` or `pyright`, everything should work.

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `boto-stubs[medialive]` in your environment: `python -m pip install 'boto3-stubs[medialive]'`
- Run `mypy` as usual

Type checking should work for `MediaLive` service.
No explicit type annotations required, write your `boto3` code as usual.

### pyright

- Install `pyright`: `yarn global add pyright`
- Install `boto-stubs[medialive]` in your environment: `python -m pip install 'boto3-stubs[medialive]'`
- Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should work for `MediaLive` service.
No explicit type annotations required, write your `boto3` code as usual.

## Explicit type annotations

### Client annotations

`MediaLiveClient` provides annotations for `boto3.client("medialive")`.

```python
import boto3

from mypy_boto3_medialive import MediaLiveClient

client: MediaLiveClient = boto3.client("medialive")

# now client usage is checked by mypy and IDE should provide code auto-complete

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: MediaLiveClient = session.client("medialive")
```

### Paginators annotations

`mypy_boto3_medialive.paginator` module contains type annotations for all paginators.

```python
from mypy_boto3_medialive import MediaLiveClient
from mypy_boto3_medialive.paginator import (
    DescribeSchedulePaginator,
    ListChannelsPaginator,
    ListInputDevicesPaginator,
    ListInputDeviceTransfersPaginator,
    ListInputSecurityGroupsPaginator,
    ListInputsPaginator,
    ListMultiplexesPaginator,
    ListMultiplexProgramsPaginator,
    ListOfferingsPaginator,
    ListReservationsPaginator,
)

client: MediaLiveClient = boto3.client("medialive")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
# VSCode requires explicit type annotations
describe_schedule_paginator: DescribeSchedulePaginator = client.get_paginator("describe_schedule")
list_channels_paginator: ListChannelsPaginator = client.get_paginator("list_channels")
list_input_device_transfers_paginator: ListInputDeviceTransfersPaginator = client.get_paginator("list_input_device_transfers")
list_input_devices_paginator: ListInputDevicesPaginator = client.get_paginator("list_input_devices")
list_input_security_groups_paginator: ListInputSecurityGroupsPaginator = client.get_paginator("list_input_security_groups")
list_inputs_paginator: ListInputsPaginator = client.get_paginator("list_inputs")
list_multiplex_programs_paginator: ListMultiplexProgramsPaginator = client.get_paginator("list_multiplex_programs")
list_multiplexes_paginator: ListMultiplexesPaginator = client.get_paginator("list_multiplexes")
list_offerings_paginator: ListOfferingsPaginator = client.get_paginator("list_offerings")
list_reservations_paginator: ListReservationsPaginator = client.get_paginator("list_reservations")
```


### Waiters annotations

`mypy_boto3_medialive.waiter` module contains type annotations for all waiters.

```python
from mypy_boto3_medialive import MediaLiveClient
from mypy_boto3_medialive.waiter import (
    ChannelCreatedWaiter,
    ChannelDeletedWaiter,
    ChannelRunningWaiter,
    ChannelStoppedWaiter,
    InputAttachedWaiter,
    InputDeletedWaiter,
    InputDetachedWaiter,
    MultiplexCreatedWaiter,
    MultiplexDeletedWaiter,
    MultiplexRunningWaiter,
    MultiplexStoppedWaiter,
)

client: MediaLiveClient = boto3.client("medialive")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
# VSCode requires explicit type annotations
channel_created_waiter: ChannelCreatedWaiter = client.get_waiter("channel_created")
channel_deleted_waiter: ChannelDeletedWaiter = client.get_waiter("channel_deleted")
channel_running_waiter: ChannelRunningWaiter = client.get_waiter("channel_running")
channel_stopped_waiter: ChannelStoppedWaiter = client.get_waiter("channel_stopped")
input_attached_waiter: InputAttachedWaiter = client.get_waiter("input_attached")
input_deleted_waiter: InputDeletedWaiter = client.get_waiter("input_deleted")
input_detached_waiter: InputDetachedWaiter = client.get_waiter("input_detached")
multiplex_created_waiter: MultiplexCreatedWaiter = client.get_waiter("multiplex_created")
multiplex_deleted_waiter: MultiplexDeletedWaiter = client.get_waiter("multiplex_deleted")
multiplex_running_waiter: MultiplexRunningWaiter = client.get_waiter("multiplex_running")
multiplex_stopped_waiter: MultiplexStoppedWaiter = client.get_waiter("multiplex_stopped")
```





### Typed dictionations

`mypy_boto3_medialive.type_defs` module contains structures and shapes assembled
to typed dictionaries for additional type checking.

```python
from mypy_boto3_medialive.type_defs import (
    AacSettingsTypeDef,
    Ac3SettingsTypeDef,
    AncillarySourceSettingsTypeDef,
    ArchiveContainerSettingsTypeDef,
    ArchiveGroupSettingsTypeDef,
    ArchiveOutputSettingsTypeDef,
    AudioChannelMappingTypeDef,
    AudioCodecSettingsTypeDef,
    AudioDescriptionTypeDef,
    AudioLanguageSelectionTypeDef,
    AudioNormalizationSettingsTypeDef,
    AudioOnlyHlsSettingsTypeDef,
    AudioPidSelectionTypeDef,
    AudioSelectorSettingsTypeDef,
    AudioSelectorTypeDef,
    AudioTrackSelectionTypeDef,
    AudioTrackTypeDef,
    AutomaticInputFailoverSettingsTypeDef,
    AvailBlankingTypeDef,
    AvailConfigurationTypeDef,
    AvailSettingsTypeDef,
    BatchDeleteResponseTypeDef,
    BatchFailedResultModelTypeDef,
    BatchScheduleActionCreateRequestTypeDef,
    BatchScheduleActionCreateResultTypeDef,
    BatchScheduleActionDeleteRequestTypeDef,
    BatchScheduleActionDeleteResultTypeDef,
    BatchStartResponseTypeDef,
    BatchStopResponseTypeDef,
    BatchSuccessfulResultModelTypeDef,
    BatchUpdateScheduleResponseTypeDef,
    BlackoutSlateTypeDef,
    BurnInDestinationSettingsTypeDef,
    CaptionDescriptionTypeDef,
    CaptionDestinationSettingsTypeDef,
    CaptionLanguageMappingTypeDef,
    CaptionSelectorSettingsTypeDef,
    CaptionSelectorTypeDef,
    CdiInputSpecificationTypeDef,
    ChannelEgressEndpointTypeDef,
    ChannelSummaryTypeDef,
    ChannelTypeDef,
    CreateChannelResponseTypeDef,
    CreateInputResponseTypeDef,
    CreateInputSecurityGroupResponseTypeDef,
    CreateMultiplexProgramResponseTypeDef,
    CreateMultiplexResponseTypeDef,
    DeleteChannelResponseTypeDef,
    DeleteMultiplexProgramResponseTypeDef,
    DeleteMultiplexResponseTypeDef,
    DeleteReservationResponseTypeDef,
    DescribeChannelResponseTypeDef,
    DescribeInputDeviceResponseTypeDef,
    DescribeInputDeviceThumbnailResponseTypeDef,
    DescribeInputResponseTypeDef,
    DescribeInputSecurityGroupResponseTypeDef,
    DescribeMultiplexProgramResponseTypeDef,
    DescribeMultiplexResponseTypeDef,
    DescribeOfferingResponseTypeDef,
    DescribeReservationResponseTypeDef,
    DescribeScheduleResponseTypeDef,
    DvbNitSettingsTypeDef,
    DvbSdtSettingsTypeDef,
    DvbSubDestinationSettingsTypeDef,
    DvbSubSourceSettingsTypeDef,
    DvbTdtSettingsTypeDef,
    Eac3SettingsTypeDef,
    EbuTtDDestinationSettingsTypeDef,
    EmbeddedSourceSettingsTypeDef,
    EncoderSettingsTypeDef,
    FeatureActivationsTypeDef,
    FecOutputSettingsTypeDef,
    FixedModeScheduleActionStartSettingsTypeDef,
    Fmp4HlsSettingsTypeDef,
    FollowModeScheduleActionStartSettingsTypeDef,
    FrameCaptureGroupSettingsTypeDef,
    FrameCaptureOutputSettingsTypeDef,
    FrameCaptureSettingsTypeDef,
    GlobalConfigurationTypeDef,
    H264ColorSpaceSettingsTypeDef,
    H264FilterSettingsTypeDef,
    H264SettingsTypeDef,
    H265ColorSpaceSettingsTypeDef,
    H265FilterSettingsTypeDef,
    H265SettingsTypeDef,
    Hdr10SettingsTypeDef,
    HlsAkamaiSettingsTypeDef,
    HlsBasicPutSettingsTypeDef,
    HlsCdnSettingsTypeDef,
    HlsGroupSettingsTypeDef,
    HlsId3SegmentTaggingScheduleActionSettingsTypeDef,
    HlsInputSettingsTypeDef,
    HlsMediaStoreSettingsTypeDef,
    HlsOutputSettingsTypeDef,
    HlsSettingsTypeDef,
    HlsTimedMetadataScheduleActionSettingsTypeDef,
    HlsWebdavSettingsTypeDef,
    InputAttachmentTypeDef,
    InputChannelLevelTypeDef,
    InputClippingSettingsTypeDef,
    InputDestinationRequestTypeDef,
    InputDestinationTypeDef,
    InputDestinationVpcTypeDef,
    InputDeviceConfigurableSettingsTypeDef,
    InputDeviceHdSettingsTypeDef,
    InputDeviceNetworkSettingsTypeDef,
    InputDeviceRequestTypeDef,
    InputDeviceSettingsTypeDef,
    InputDeviceSummaryTypeDef,
    InputLocationTypeDef,
    InputLossBehaviorTypeDef,
    InputPrepareScheduleActionSettingsTypeDef,
    InputSecurityGroupTypeDef,
    InputSettingsTypeDef,
    InputSourceRequestTypeDef,
    InputSourceTypeDef,
    InputSpecificationTypeDef,
    InputSwitchScheduleActionSettingsTypeDef,
    InputTypeDef,
    InputVpcRequestTypeDef,
    InputWhitelistRuleCidrTypeDef,
    InputWhitelistRuleTypeDef,
    KeyProviderSettingsTypeDef,
    ListChannelsResponseTypeDef,
    ListInputDevicesResponseTypeDef,
    ListInputDeviceTransfersResponseTypeDef,
    ListInputSecurityGroupsResponseTypeDef,
    ListInputsResponseTypeDef,
    ListMultiplexesResponseTypeDef,
    ListMultiplexProgramsResponseTypeDef,
    ListOfferingsResponseTypeDef,
    ListReservationsResponseTypeDef,
    ListTagsForResourceResponseTypeDef,
    M2tsSettingsTypeDef,
    M3u8SettingsTypeDef,
    MediaConnectFlowRequestTypeDef,
    MediaConnectFlowTypeDef,
    MediaPackageGroupSettingsTypeDef,
    MediaPackageOutputDestinationSettingsTypeDef,
    Mp2SettingsTypeDef,
    Mpeg2FilterSettingsTypeDef,
    Mpeg2SettingsTypeDef,
    MsSmoothGroupSettingsTypeDef,
    MsSmoothOutputSettingsTypeDef,
    MultiplexMediaConnectOutputDestinationSettingsTypeDef,
    MultiplexOutputDestinationTypeDef,
    MultiplexOutputSettingsTypeDef,
    MultiplexProgramChannelDestinationSettingsTypeDef,
    MultiplexProgramPacketIdentifiersMapTypeDef,
    MultiplexProgramPipelineDetailTypeDef,
    MultiplexProgramServiceDescriptorTypeDef,
    MultiplexProgramSettingsTypeDef,
    MultiplexProgramSummaryTypeDef,
    MultiplexProgramTypeDef,
    MultiplexSettingsSummaryTypeDef,
    MultiplexSettingsTypeDef,
    MultiplexStatmuxVideoSettingsTypeDef,
    MultiplexSummaryTypeDef,
    MultiplexTypeDef,
    MultiplexVideoSettingsTypeDef,
    NetworkInputSettingsTypeDef,
    NielsenConfigurationTypeDef,
    OfferingTypeDef,
    OutputDestinationSettingsTypeDef,
    OutputDestinationTypeDef,
    OutputGroupSettingsTypeDef,
    OutputGroupTypeDef,
    OutputLocationRefTypeDef,
    OutputSettingsTypeDef,
    OutputTypeDef,
    PaginatorConfigTypeDef,
    PauseStateScheduleActionSettingsTypeDef,
    PipelineDetailTypeDef,
    PipelinePauseStateSettingsTypeDef,
    PurchaseOfferingResponseTypeDef,
    RemixSettingsTypeDef,
    ReservationResourceSpecificationTypeDef,
    ReservationTypeDef,
    ResponseMetadata,
    RtmpGroupSettingsTypeDef,
    RtmpOutputSettingsTypeDef,
    ScheduleActionSettingsTypeDef,
    ScheduleActionStartSettingsTypeDef,
    ScheduleActionTypeDef,
    Scte20SourceSettingsTypeDef,
    Scte27SourceSettingsTypeDef,
    Scte35DeliveryRestrictionsTypeDef,
    Scte35DescriptorSettingsTypeDef,
    Scte35DescriptorTypeDef,
    Scte35ReturnToNetworkScheduleActionSettingsTypeDef,
    Scte35SegmentationDescriptorTypeDef,
    Scte35SpliceInsertScheduleActionSettingsTypeDef,
    Scte35SpliceInsertTypeDef,
    Scte35TimeSignalAposTypeDef,
    Scte35TimeSignalScheduleActionSettingsTypeDef,
    StandardHlsSettingsTypeDef,
    StartChannelResponseTypeDef,
    StartMultiplexResponseTypeDef,
    StartTimecodeTypeDef,
    StaticImageActivateScheduleActionSettingsTypeDef,
    StaticImageDeactivateScheduleActionSettingsTypeDef,
    StaticKeySettingsTypeDef,
    StopChannelResponseTypeDef,
    StopMultiplexResponseTypeDef,
    StopTimecodeTypeDef,
    TeletextSourceSettingsTypeDef,
    TemporalFilterSettingsTypeDef,
    TimecodeConfigTypeDef,
    TransferringInputDeviceSummaryTypeDef,
    TtmlDestinationSettingsTypeDef,
    UdpContainerSettingsTypeDef,
    UdpGroupSettingsTypeDef,
    UdpOutputSettingsTypeDef,
    UpdateChannelClassResponseTypeDef,
    UpdateChannelResponseTypeDef,
    UpdateInputDeviceResponseTypeDef,
    UpdateInputResponseTypeDef,
    UpdateInputSecurityGroupResponseTypeDef,
    UpdateMultiplexProgramResponseTypeDef,
    UpdateMultiplexResponseTypeDef,
    UpdateReservationResponseTypeDef,
    VideoCodecSettingsTypeDef,
    VideoDescriptionTypeDef,
    VideoSelectorPidTypeDef,
    VideoSelectorProgramIdTypeDef,
    VideoSelectorSettingsTypeDef,
    VideoSelectorTypeDef,
    WaiterConfigTypeDef,
    WavSettingsTypeDef,
)

def get_structure() -> AacSettingsTypeDef:
    return {
      ...
    }
```
